<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>אודות Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>מחברים</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>מתרגמים</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>תודות</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>הסכם רישוי</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>נגן מולטימדיה מבוסס ‏Qt ‏(Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="67"/>
        <source>Version: %1</source>
        <translation>גירסה: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation>משתמש בספריית Qt %1 (הודר בעזרת Qt %2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>‏(c) ‏%1-%2 נבחרת הפיתוח של Qmmp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Input plugins:</source>
        <translation>תוספות קלט:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="85"/>
        <source>Output plugins:</source>
        <translation>תוספות פלט:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Visual plugins:</source>
        <translation>תוספות חזותיות:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="103"/>
        <source>Effect plugins:</source>
        <translation>תוספות אפקט:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="112"/>
        <source>General plugins:</source>
        <translation>תוספות כלליות:</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>הזנת URL להוספה</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="43"/>
        <source>&amp;Add</source>
        <translation>&amp;הוסף</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="50"/>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="124"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>הגדרות Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>רשימת השמעה</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>תוספות</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>מתקדמות</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>קישוריות</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="757"/>
        <source>Audio</source>
        <translation>שמע</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>מידע-מוצמד</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="135"/>
        <source>Load metadata from files</source>
        <translation>טען מידע-מוצמד מן קבצים</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="142"/>
        <source>Convert underscores to blanks</source>
        <translation>המר הדגשות אל תווי רווח</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="149"/>
        <source>Convert %20 to blanks</source>
        <translation>המר ‎%20 אל תווי רווח</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="156"/>
        <source>Title format:</source>
        <translation>פורמט כותרת:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="166"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="176"/>
        <source>Directory Scanning Options</source>
        <translation>אפשרויות סריקת מדור</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="182"/>
        <source>Restrict files to:</source>
        <translation>הגבל קבצים אל:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="192"/>
        <location filename="../forms/configdialog.ui" line="436"/>
        <source>Exclude files:</source>
        <translation>הוצא קבצים:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="205"/>
        <source>Miscellaneous</source>
        <translation>שונות</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="211"/>
        <source>Auto-save playlist when modified</source>
        <translation>שמור אוטומטית רשימת השמעה כאשר משתנה</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <source>Look and Feel</source>
        <translation>מראה ותחושה</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="337"/>
        <source>Language:</source>
        <translation>שפה:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="410"/>
        <source>Cover Image Retrieve</source>
        <translation>אחזור תמונת כיסוי</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="416"/>
        <source>Use separate image files</source>
        <translation>השתמש בקבצי תמונה פרודים</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="426"/>
        <source>Include files:</source>
        <translation>הכלל קבצים:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="448"/>
        <source>Recursive search depth:</source>
        <translation>חיפוש עומק רקורסיבי:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="259"/>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="272"/>
        <source>Information</source>
        <translation>מידע</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="314"/>
        <source>Description</source>
        <translation>תיאור</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="319"/>
        <source>Filename</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="373"/>
        <source>Playback</source>
        <translation>פס קול</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>Continue playback on startup</source>
        <translation>המשך ניגון פס קול בעת הפעלה</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="386"/>
        <source>Determine file type by content</source>
        <translation>קבע טיפוס קובץ על פי תוכן</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Add files from command line to this playlist:</source>
        <translation>הוסף קבצים מן שורת פקודה אל רשימת השמעה זו:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>URL Dialog</source>
        <translation>דו שיח URL</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="486"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>הדבק אוטומטית URL מן לוח גזירה</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="525"/>
        <source>Proxy</source>
        <translation>פרוקסי</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="537"/>
        <source>Enable proxy usage</source>
        <translation>אפשר שימוש בפרוקסי</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="544"/>
        <source>Proxy host name:</source>
        <translation>שם מארח פרוקסי:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="557"/>
        <source>Proxy port:</source>
        <translation>פורט פרוקסי:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="570"/>
        <source>Use authentication with proxy</source>
        <translation>השתמש באימות עם פרוקסי</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="577"/>
        <source>Proxy user name:</source>
        <translation>שם משתמש פרוקסי:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="590"/>
        <source>Proxy password:</source>
        <translation>סיסמת פרוקסי:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="627"/>
        <source>Replay Gain</source>
        <translation>הגברת שמע</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="633"/>
        <source>Replay Gain mode:</source>
        <translation>מצב הגברת שמע:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="650"/>
        <source>Preamp:</source>
        <translation>מגבר קדמי:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="682"/>
        <location filename="../forms/configdialog.ui" line="727"/>
        <source>dB</source>
        <translation>דציבל</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="695"/>
        <source>Default gain:</source>
        <translation>מגבר משתמט:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="747"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>השתמש במידע שיא למניעת קיצץ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="763"/>
        <source>Buffer size:</source>
        <translation>שיעור אגירה:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="782"/>
        <source>ms</source>
        <translation>מ״ש</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="811"/>
        <source>Use software volume control</source>
        <translation>נצל בקרת שמע של תוכנה</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="818"/>
        <source>16-bit output</source>
        <translation>פלט 16 סיביות</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Track</source>
        <translation>רצועה</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <location filename="../configdialog.cpp" line="287"/>
        <source>Album</source>
        <translation>אלבום</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="69"/>
        <source>Disabled</source>
        <translation>מנוטרלת</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="174"/>
        <source>Transports</source>
        <translation>מובילים</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="184"/>
        <source>Decoders</source>
        <translation>מפענחים</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="194"/>
        <source>Engines</source>
        <translation>מנועים</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="204"/>
        <source>Effects</source>
        <translation>אפקטים</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="214"/>
        <source>Visualization</source>
        <translation>חיזוי</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="224"/>
        <source>General</source>
        <translation>כללי</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="234"/>
        <source>Output</source>
        <translation>פלט</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>File Dialogs</source>
        <translation>תיבות דו שיח קובץ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="254"/>
        <source>User Interfaces</source>
        <translation>ממשקי משתמש</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="286"/>
        <source>Artist</source>
        <translation>אמן</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="288"/>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="289"/>
        <source>Track number</source>
        <translation>מספר רצועה</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="290"/>
        <source>Two-digit track number</source>
        <translation>מספר רצועה דו ספרתי</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="291"/>
        <source>Genre</source>
        <translation>ז&apos;אנר</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="292"/>
        <source>Comment</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="293"/>
        <source>Composer</source>
        <translation>מלחין</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="294"/>
        <source>Disc number</source>
        <translation>מספר תקליטור</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>File name</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="296"/>
        <source>File path</source>
        <translation>נתיב קובץ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="297"/>
        <source>Year</source>
        <translation>שנה</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="298"/>
        <source>Condition</source>
        <translation>תנאי</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="308"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;איתור אוטומטי&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="309"/>
        <source>Brazilian Portuguese</source>
        <translation>ברזילאית פורטוגזית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="310"/>
        <source>Chinese Simplified</source>
        <translation>סינית מפושטת</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="311"/>
        <source>Chinese Traditional</source>
        <translation>סינית מסורתית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="312"/>
        <source>Czech</source>
        <translation>צ׳כית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="313"/>
        <source>Dutch</source>
        <translation>הולנדית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="314"/>
        <source>English</source>
        <translation>אנגלית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="315"/>
        <source>French</source>
        <translation>צרפתית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="316"/>
        <source>Galician</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="317"/>
        <source>German</source>
        <translation>גרמנית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="318"/>
        <source>Hebrew</source>
        <translation>עברית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="319"/>
        <source>Hungarian</source>
        <translation>הונגרית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="320"/>
        <source>Italian</source>
        <translation>איטלקית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="321"/>
        <source>Japanese</source>
        <translation>יפנית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="322"/>
        <source>Kazakh</source>
        <translation>קזחית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="323"/>
        <source>Lithuanian</source>
        <translation>ליטאית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="324"/>
        <source>Polish</source>
        <translation>פולנית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="325"/>
        <source>Russian</source>
        <translation>רוסית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="326"/>
        <source>Slovak</source>
        <translation>סלובקית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="327"/>
        <source>Spanish</source>
        <translation>ספרדית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="328"/>
        <source>Turkish</source>
        <translation>טורקית</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="329"/>
        <source>Ukrainian</source>
        <translation>אוקראינית</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>פרטים</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="42"/>
        <source>Open the directory containing this file</source>
        <translation>פתח את המדור שמכיל את קובץ זה</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="45"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="59"/>
        <source>Summary</source>
        <translation>סיכום</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="110"/>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="111"/>
        <source>Artist</source>
        <translation>אמן</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="112"/>
        <source>Album</source>
        <translation>אלבום</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="114"/>
        <source>Genre</source>
        <translation>ז&apos;אנר</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="115"/>
        <source>Composer</source>
        <translation>מלחין</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="117"/>
        <source>Year</source>
        <translation>שנה</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="119"/>
        <source>Track</source>
        <translation>רצועה</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="121"/>
        <source>Disc number</source>
        <translation>מספר תקליטור</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>קפוץ אל רצועה</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>סינון</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="92"/>
        <location filename="../jumptotrackdialog.cpp" line="145"/>
        <source>Queue</source>
        <translation>תור</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>רענן</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>קפוץ אל</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="59"/>
        <source>Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="60"/>
        <source>J</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="61"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="90"/>
        <location filename="../jumptotrackdialog.cpp" line="143"/>
        <source>Unqueue</source>
        <translation>הוצא מן תור</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="108"/>
        <source>Unsupported playlist format</source>
        <translation>פורמט רשימת השמעה לא נתמך</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="164"/>
        <location filename="../playlistmanager.cpp" line="352"/>
        <source>Playlist</source>
        <translation>רשימת השמעה</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="42"/>
        <source>Playlist</source>
        <translation>רשימת השמעה</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="34"/>
        <source>Qt File Dialog</source>
        <translation>דו שיח קובץ Qt</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>עורך תגית</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>כותרת:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>אמן:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>אלבום:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Composer:</source>
        <translation>מלחין:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="133"/>
        <source>Genre:</source>
        <translation>ז&apos;אנר:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="163"/>
        <source>Track:</source>
        <translation>רצועה:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="184"/>
        <location filename="../forms/tageditor.ui" line="222"/>
        <location filename="../forms/tageditor.ui" line="254"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="197"/>
        <source>Year:</source>
        <translation>שנה:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="244"/>
        <source>Disc number:</source>
        <translation>מספר תקליטור:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="269"/>
        <source>Comment:</source>
        <translation>הערה:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="305"/>
        <source>Include selected tag in file</source>
        <translation>הכלל תגית נבחרת בקובץ</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>עורך תבנית</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>איפוס</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>שיבוץ</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation>אמן</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation>אלבום</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Track number</source>
        <translation>מספר רצועה</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Two-digit track number</source>
        <translation>מספר רצועה דו ספרתי</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Genre</source>
        <translation>ז&apos;אנר</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Comment</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Composer</source>
        <translation>מלחין</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Duration</source>
        <translation>משך</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Disc number</source>
        <translation>מספר תקליטור</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>File name</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File path</source>
        <translation>נתיב קובץ</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>Year</source>
        <translation>שנה</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Condition</source>
        <translation>תנאי</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="134"/>
        <source>All Supported Bitstreams</source>
        <translation>כל זרמי הסביות הנתמכים</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="139"/>
        <source>Select one or more files to open</source>
        <translation>בחר קובץ אחד או יותר לפתיחה</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="146"/>
        <source>Choose a directory</source>
        <translation>בחר מדור</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="162"/>
        <location filename="../uihelper.cpp" line="183"/>
        <source>Playlist Files</source>
        <translation>קבצי רשימת השמעה</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="164"/>
        <source>Open Playlist</source>
        <translation>פתח רשימת השמעה</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="184"/>
        <source>Save Playlist</source>
        <translation>שמור רשימת השמעה</translation>
    </message>
</context>
</TS>
